@@ -18,6 +18,7 @@
 import glob
 import os
 import re
+import shutil
 import logging
 from contextlib import ExitStack
 
@@ -154,7 +155,7 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
             self.target = 'i386-pc'
             self.install_device = self.device
             self.modules = ' '.join(
-                Defaults.get_grub_bios_modules(multiboot=True)
+                Defaults.get_grub_platform_modules(multiboot=True)
             )
             self.install_arguments.append('--skip-fs-probe')
         elif self.arch.startswith('ppc64'):
@@ -175,8 +176,7 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
             self.install_arguments.append('--no-nvram')
         else:
             raise KiwiBootLoaderGrubPlatformError(
-                'host architecture %s not supported for grub2 installation' %
-                self.arch
+                f'host architecture {self.arch} not supported for grub2 installation'
             )
 
         with ExitStack() as stack:
@@ -400,17 +400,13 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
                 [grub2_install, '.orig']
             )
             grub2_install_noop = '/bin/true'
-            Command.run(
-                [
-                    'chroot', root_path,
-                    'cp', '-p', grub2_install, grub2_install_backup
-                ]
+            shutil.copy2(
+                os.path.normpath(f'{root_path}/{grub2_install}'),
+                os.path.normpath(f'{root_path}/{grub2_install_backup}')
             )
-            Command.run(
-                [
-                    'chroot', root_path,
-                    'cp', grub2_install_noop, grub2_install
-                ]
+            shutil.copy2(
+                os.path.normpath(f'{root_path}/{grub2_install_noop}'),
+                os.path.normpath(f'{root_path}/{grub2_install}')
             )
 
     def _enable_grub2_install(self, root_path):
