@@ -756,6 +756,14 @@ class KiwiVolumeManagerSetupError(KiwiError):
     """
 
 
+class KiwiSnapshotManagerSetupError(KiwiError):
+    """
+    Exception raised if an attempt was made to create an
+    instance of a snapshot manager for an unsupported snapshot
+    management system.
+    """
+
+
 class KiwiVolumeRootIDError(KiwiError):
     """
     Exception raised if the root volume can not be found. This
@@ -874,3 +882,10 @@ class KiwiEnclaveFormatError(KiwiError):
     Exception raised if no enclave_format attribute specified
     for the selected build type
     """
+
+
+class KiwiCATargetDistributionError(KiwiError):
+    """
+    Exception raised if no CA target distribution can be found
+    but the request to import custom CA certificates was issued
+    """
