@@ -86,11 +86,12 @@ class RuntimeChecker:
         message = dedent('''\n
             Target root/image directory is lacking filesystem features
 
-            The filesystem {0} for the given image target directory {1}
+            The filesystem {0} in the target path {1}
             does not support important features like extended permissions,
             ACLs or xattrs. The image build may fail or the resulting
             image misbehave.
         ''')
+        target_dir = Path.first_exists(target_dir)
         stat = Command.run(['stat', '-f', '-c', '%T', target_dir])
         if stat:
             target_fs = stat.output.strip()
@@ -679,22 +680,22 @@ class RuntimeChecker:
             {1}
         ''')
         kiwi_dracut_modules = {
-            '90kiwi-dump': dracut_module_type(
+            '55kiwi-dump': dracut_module_type(
                 'dracut-kiwi-oem-dump', '9.20.1'
             ),
-            '90kiwi-live': dracut_module_type(
+            '55kiwi-live': dracut_module_type(
                 'dracut-kiwi-live', '9.20.1'
             ),
-            '90kiwi-overlay': dracut_module_type(
+            '55kiwi-overlay': dracut_module_type(
                 'dracut-kiwi-overlay', '9.20.1'
             ),
-            '90kiwi-repart': dracut_module_type(
+            '55kiwi-repart': dracut_module_type(
                 'dracut-kiwi-oem-repart', '9.20.1'
             ),
-            '99kiwi-dump-reboot': dracut_module_type(
+            '59kiwi-dump-reboot': dracut_module_type(
                 'dracut-kiwi-oem-dump', '9.20.1'
             ),
-            '99kiwi-lib': dracut_module_type(
+            '59kiwi-lib': dracut_module_type(
                 'dracut-kiwi-lib', '9.20.1'
             )
         }
@@ -957,7 +958,7 @@ class RuntimeChecker:
             Conflicting image type setup detected
 
             The selected image type '{0}' in the {1} profile
-            selection is not unique. There are the followng type
+            selection is not unique. There are the following type
             settings which overrides each other:
             {2}
             To solve this conflict please move the image type
