@@ -60,6 +60,9 @@ class DiskFormatBase:
 
         self.post_init(custom_args or {})
 
+    def __enter__(self):
+        return self
+
     def post_init(self, custom_args: dict) -> None:
         """
         Post initialization method
@@ -161,7 +164,7 @@ class DiskFormatBase:
         if format_name != 'raw':
             if format_name not in Defaults.get_disk_format_types():
                 raise KiwiFormatSetupError(
-                    'unsupported disk format %s' % format_name
+                    f'unsupported disk format {format_name}'
                 )
         return ''.join(
             [
@@ -185,19 +188,19 @@ class DiskFormatBase:
 
         :param object result: Instance of Result
         """
+        compression = self.runtime_config.get_bundle_compression(default=True)
+        if self.xml_state.get_luks_credentials() is not None:
+            compression = False
         result.add(
             key='disk_format_image',
             filename=self.get_target_file_path_for_format(
                 self.image_format
             ),
             use_for_bundle=True,
-            compress=self.runtime_config.get_bundle_compression(
-                default=True
-            ),
+            compress=compression,
             shasum=True
         )
 
-    def __del__(self):
+    def __exit__(self, exc_type, exc_value, traceback):
         if self.temp_image_dir and os.path.exists(self.temp_image_dir):
-            log.info('Cleaning up %s instance', type(self).__name__)
             Path.wipe(self.temp_image_dir)
