@@ -21,6 +21,7 @@ usage: kiwi-ng result bundle -h | --help
            [--bundle-format=<format>]
            [--zsync-source=<download_location>]
            [--package-as-rpm]
+           [--no-compress]
        kiwi-ng result bundle help
 
 commands:
@@ -54,6 +55,8 @@ options:
         If provided this setting will overwrite an eventually
         provided bundle_format attribute from the main
         image description
+    --no-compress
+        Do not compress the result image file(s)
 """
 from collections import OrderedDict
 from textwrap import dedent
@@ -231,7 +234,7 @@ class ResultBundleTask(CliTask):
                 bundle_file = ''.join(
                     [bundle_directory, '/', bundle_file_basename]
                 )
-                if result_file.compress:
+                if result_file.compress and not self.command_args['--no-compress']:
                     log.info('--> Compressing')
                     compress = Compress(bundle_file)
                     bundle_file = compress.xz(self.runtime_config.get_xz_options())
@@ -286,10 +289,11 @@ class ResultBundleTask(CliTask):
     ) -> str:
         image_version = result.xml_state.get_image_version()
         image_name = result.xml_state.xml_data.get_name()
-        if '.tar.' in result_file.filename:
+        special_exts = ['.oci.tar.', '.docker.tar.', '.vagrant.']
+        if any(special_ext in result_file.filename for special_ext in special_exts):
+            extension = f'{".".join(result_file.filename.split(".")[-3:])}'
+        elif '.tar.' in result_file.filename:
             extension = f'tar.{result_file.filename.split(".").pop()}'
-        elif '.vagrant.' in result_file.filename:
-            extension = f'vagrant.{".".join(result_file.filename.split(".")[-2:])}'
         else:
             extension = result_file.filename.split('.').pop()
         if bundle_file_format_name:
