@@ -18,10 +18,6 @@
 import re
 import os
 import logging
-import shutil
-import datetime
-from xml.etree import ElementTree
-from xml.dom import minidom
 from typing import List
 
 # project
@@ -32,9 +28,9 @@ from kiwi.storage.mapped_device import MappedDevice
 from kiwi.filesystem import FileSystem
 from kiwi.utils.sync import DataSync
 from kiwi.utils.block import BlockID
-from kiwi.utils.sysconfig import SysConfig
 from kiwi.path import Path
 from kiwi.defaults import Defaults
+from kiwi.snapshot_manager import SnapshotManager
 
 from kiwi.exceptions import (
     KiwiVolumeRootIDError,
@@ -92,8 +88,10 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             log.warning('root_is_snapper_snapshot has been disabled')
             self.custom_args['root_is_snapper_snapshot'] = False
 
+        self.snapper = None
         self.subvol_mount_list = []
         self.toplevel_mount = None
+        self.root_volume_mount = None
         self.snapshots_root_mount = None
 
     def setup(self, name=None):
@@ -136,39 +134,29 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 ['btrfs', 'subvolume', 'create', root_volume]
             )
         if self.custom_args['root_is_snapper_snapshot']:
-            snapshot_volume = self.mountpoint + \
-                f'/{self.root_volume_name}/.snapshots'
-            Command.run(
-                ['btrfs', 'subvolume', 'create', snapshot_volume]
+            self.snapper = SnapshotManager.new(
+                'snapper', self.device, self.root_dir, self.mountpoint,
+                self.root_volume_name,
+                {'quota_groups': self.custom_args['quota_groups']}
             )
-            os.chmod(snapshot_volume, 0o700)
-            Path.create(snapshot_volume + '/1')
-            snapshot = self.mountpoint + \
-                f'/{self.root_volume_name}/.snapshots/1/snapshot'
-            Command.run(
-                ['btrfs', 'subvolume', 'create', snapshot]
-            )
-            self._set_default_volume(
-                f'{self.root_volume_name}/.snapshots/1/snapshot'
-            )
-            snapshot = self.mountpoint + \
-                f'/{self.root_volume_name}/.snapshots/1/snapshot'
-            # Mount /{some-name}/.snapshots as /.snapshots inside the root
-            snapshots_mount = MountManager(
-                device=self.device,
-                attributes={
-                    'subvol_path': f'{self.root_volume_name}/.snapshots',
-                    'subvol_name': f'{self.root_volume_name}/.snapshots'
-                },
-                mountpoint=snapshot + '/.snapshots'
-            )
-            self.subvol_mount_list.append(snapshots_mount)
+            mounts = self.snapper.create_first_snapshot()
+            for mnt in mounts:
+                self.subvol_mount_list.append(mnt)
             # make sure the snapshot appears as proper (/) in the chroot
             self.snapshots_root_mount = MountManager(
                 device=self.get_mountpoint(), mountpoint=self.get_mountpoint()
             )
+            self.default_volume_name = self.snapper.get_default_snapshot_name()
         elif self.root_volume_name != '/':
             self._set_default_volume(self.root_volume_name)
+            # make sure the root volume appears as proper (/) in the chroot
+            root_dir = os.path.normpath(
+                os.sep.join([self.mountpoint, self.get_root_volume_name()])
+            )
+            self.root_volume_mount = MountManager(
+                device=root_dir, mountpoint=root_dir
+            )
+            self.root_volume_mount.bind_mount()
 
     def get_root_volume_name(self) -> str:
         """
@@ -390,6 +378,9 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         if self.snapshots_root_mount and self.snapshots_root_mount.is_mounted():
             self.snapshots_root_mount.umount()
 
+        if self.root_volume_mount:
+            self.root_volume_mount.umount()
+
         if self.toplevel_mount.is_mounted():
             self.toplevel_mount.umount()
 
@@ -423,22 +414,12 @@ class VolumeManagerBtrfs(VolumeManagerBase):
         """
         if self.toplevel_mount:
             sync_target = self.get_mountpoint()
-            if self.custom_args['root_is_snapper_snapshot']:
-                self._create_snapshot_info(
-                    ''.join(
-                        [
-                            self.mountpoint,
-                            f'/{self.root_volume_name}/.snapshots/1/info.xml'
-                        ]
-                    )
-                )
             data = DataSync(self.root_dir, sync_target)
             data.sync_data(
                 options=Defaults.get_sync_options(), exclude=exclude
             )
-            if self.custom_args['quota_groups'] and \
-               self.custom_args['root_is_snapper_snapshot']:
-                self._create_snapper_quota_configuration()
+            if self.custom_args['root_is_snapper_snapshot']:
+                self.snapper.setup_first_snapshot()
 
     def set_property_readonly_root(self):
         """
@@ -513,76 +494,8 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             f'Failed to find btrfs volume: {default_volume}'
         )
 
-    def _xml_pretty(self, toplevel_element):
-        xml_data_unformatted = ElementTree.tostring(
-            toplevel_element, 'utf-8'
-        )
-        xml_data_domtree = minidom.parseString(xml_data_unformatted)
-        return xml_data_domtree.toprettyxml(indent="    ")
-
-    def _create_snapper_quota_configuration(self):
-        root_path = os.sep.join(
-            [
-                self.mountpoint,
-                f'{self.root_volume_name}/.snapshots/1/snapshot'
-            ]
-        )
-        snapper_default_conf = Defaults.get_snapper_config_template_file(
-            root_path
-        )
-        if snapper_default_conf:
-            # snapper requires an extra parent qgroup to operate with quotas
-            Command.run(
-                ['btrfs', 'qgroup', 'create', '1/0', self.mountpoint]
-            )
-            config_file = self._set_snapper_sysconfig_file(root_path)
-            if not os.path.exists(config_file):
-                shutil.copyfile(snapper_default_conf, config_file)
-            Command.run([
-                'chroot', root_path, 'snapper', '--no-dbus', 'set-config',
-                'QGROUP=1/0'
-            ])
-
-    @staticmethod
-    def _set_snapper_sysconfig_file(root_path):
-        sysconf_file = SysConfig(
-            os.sep.join([root_path, 'etc/sysconfig/snapper'])
-        )
-        if not sysconf_file.get('SNAPPER_CONFIGS') or \
-           len(sysconf_file['SNAPPER_CONFIGS'].strip('\"')) == 0:
-
-            sysconf_file['SNAPPER_CONFIGS'] = '"root"'
-            sysconf_file.write()
-        elif len(sysconf_file['SNAPPER_CONFIGS'].split()) > 1:
-            raise KiwiVolumeManagerSetupError(
-                'Unsupported SNAPPER_CONFIGS value: {0}'.format(
-                    sysconf_file['SNAPPER_CONFIGS']
-                )
-            )
-        return os.sep.join([
-            root_path, 'etc/snapper/configs',
-            sysconf_file['SNAPPER_CONFIGS'].strip('\"')]
-        )
-
-    def _create_snapshot_info(self, filename):
-        date_info = datetime.datetime.now()
-        snapshot = ElementTree.Element('snapshot')
-
-        snapshot_type = ElementTree.SubElement(snapshot, 'type')
-        snapshot_type.text = 'single'
-
-        snapshot_number = ElementTree.SubElement(snapshot, 'num')
-        snapshot_number.text = '1'
-
-        snapshot_description = ElementTree.SubElement(snapshot, 'description')
-        snapshot_description.text = 'first root filesystem'
-
-        snapshot_date = ElementTree.SubElement(snapshot, 'date')
-        snapshot_date.text = date_info.strftime("%Y-%m-%d %H:%M:%S")
-
-        with open(filename, 'w') as snapshot_info_file:
-            snapshot_info_file.write(self._xml_pretty(snapshot))
-
     def __exit__(self, exc_type, exc_value, traceback):
+        if self.root_volume_mount:
+            self.root_volume_mount.umount()
         if self.toplevel_mount:
             self.umount_volumes()
