@@ -95,115 +95,9 @@ class TestBootLoaderTemplateGrub2:
             terminal_output='console'
         )
 
-    def test_get_install_template_console_no_hybrid(self):
-        assert self.grub2.get_install_template(
-            has_graphics=False,
-            hybrid=False
-        ).substitute(
-            search_params='--file --set=root /boot/0xd305fb7d',
-            default_boot='0',
-            kernel_file='boot/linux.vmx',
-            initrd_file='boot/initrd.vmx',
-            boot_options='cdinst=1 splash',
-            failsafe_boot_options='cdinst=1 splash',
-            boot_timeout='10',
-            boot_timeout_style='menu',
-            serial_line_setup='',
-            title='LimeJeOS-SLE12-Community [ VMX ]',
-            bootpath='/boot',
-            efi_image_name='bootx64.efi',
-            terminal_input='console',
-            terminal_output='console'
-        )
-
-    def test_get_install_template_serial_no_hybrid(self):
-        assert self.grub2.get_install_template(
-            has_graphics=False,
-            hybrid=False
-        ).substitute(
-            search_params='--file --set=root /boot/0xd305fb7d',
-            default_boot='0',
-            kernel_file='boot/linux.vmx',
-            initrd_file='boot/initrd.vmx',
-            boot_options='cdinst=1 splash',
-            failsafe_boot_options='cdinst=1 splash',
-            boot_timeout='10',
-            boot_timeout_style='menu',
-            serial_line_setup='',
-            title='LimeJeOS-SLE12-Community [ VMX ]',
-            bootpath='/boot',
-            efi_image_name='bootx64.efi',
-            terminal_input='serial',
-            terminal_output='serial'
-        )
-
     def test_get_iso_template(self):
-        assert self.grub2.get_iso_template().substitute(
-            search_params='--file --set=root /boot/0xd305fb7d',
-            default_boot='0',
-            kernel_file='boot/linux.vmx',
-            initrd_file='boot/initrd.vmx',
-            boot_options='splash',
-            failsafe_boot_options='splash',
-            gfxmode='800x600',
-            theme='SLE',
-            boot_timeout='10',
-            boot_timeout_style='menu',
-            serial_line_setup='',
-            title='LimeJeOS-SLE12-Community',
-            bootpath='/boot',
-            boot_directory_name='grub2',
-            efi_image_name='bootx64.efi',
-            terminal_input='console',
-            terminal_output='console'
-        )
-
-    def test_get_iso_template_console_no_hybrid(self):
         assert self.grub2.get_iso_template(
-            has_graphics=False,
-            hybrid=False
-        ).substitute(
-            search_params='--file --set=root /boot/0xd305fb7d',
-            default_boot='0',
-            kernel_file='boot/linux.vmx',
-            initrd_file='boot/initrd.vmx',
-            boot_options='splash',
-            failsafe_boot_options='splash',
-            boot_timeout='10',
-            boot_timeout_style='menu',
-            serial_line_setup='',
-            title='LimeJeOS-SLE12-Community',
-            bootpath='/boot',
-            efi_image_name='bootx64.efi',
-            terminal_input='console',
-            terminal_output='console'
-        )
-
-    def test_get_iso_template_serial_no_hybrid(self):
-        assert self.grub2.get_iso_template(
-            has_graphics=False,
-            has_serial=True,
-            hybrid=False
-        ).substitute(
-            search_params='--file --set=root /boot/0xd305fb7d',
-            default_boot='0',
-            kernel_file='boot/linux.vmx',
-            initrd_file='boot/initrd.vmx',
-            boot_options='splash',
-            failsafe_boot_options='splash',
-            boot_timeout='10',
-            boot_timeout_style='menu',
-            serial_line_setup='',
-            title='LimeJeOS-SLE12-Community',
-            bootpath='/boot',
-            efi_image_name='bootx64.efi',
-            terminal_input='serial',
-            terminal_output='serial'
-        )
-
-    def test_get_iso_template_checkiso_no_hybrid(self):
-        assert self.grub2.get_iso_template(
-            hybrid=False, checkiso=True
+            has_serial=True
         ).substitute(
             search_params='--file --set=root /boot/0xd305fb7d',
             default_boot='0',
