@@ -62,6 +62,8 @@ class TestCli:
             '--set-repo-credentials': None,
             '--add-package': [],
             '--add-bootstrap-package': [],
+            '--ca-cert': [],
+            '--ca-target-distribution': None,
             '--delete-package': [],
             '--set-container-derived-from': None,
             '--set-container-tag': None,
