@@ -24,14 +24,28 @@ class TestFileSystemFat32:
 
     @patch('kiwi.filesystem.fat32.Command.run')
     def test_create_on_device(self, mock_command):
-        self.fat32.create_on_device('label', 100, uuid='uuid')
-        call = mock_command.call_args_list[0]
-        assert mock_command.call_args_list[0] == call(
-            [
-                'mkdosfs', '-F32', '-I', '-n', 'label',
-                '-i', 'uuid', '/dev/foo', '100'
-            ]
-        )
+        with patch.dict('os.environ', {'SOURCE_DATE_EPOCH': '0'}):
+            self.fat32.create_on_device(
+                'label', 100, uuid='12345678-1234-5678-1234-567812345678'
+            )
+            call = mock_command.call_args_list[0]
+            assert mock_command.call_args_list[0] == call(
+                [
+                    'mkdosfs', '-F32', '-I', '-n', 'label',
+                    '-i', '12345678', '/dev/foo', '100'
+                ]
+            )
+            mock_command.reset_mock()
+            self.fat32.create_on_device('label', 100)
+            assert mock_command.call_args_list[0] == call(
+                [
+                    'mkdosfs', '-F32', '-I',
+                    '-n', 'label',
+                    '-i', '2453562E',
+                    '/dev/foo',
+                    '100'
+                ]
+            )
 
     @patch('kiwi.filesystem.fat32.Command.run')
     def test_set_uuid(self, mock_command):
