@@ -72,7 +72,8 @@ class TestXMLState:
         self.bootloader.get_timeout_style.return_value = 'some-style'
         self.bootloader.get_targettype.return_value = 'some-target'
         self.bootloader.get_bls.return_value = False
-        self.bootloader.get_console.return_value = 'some-console'
+        self.bootloader.get_output_console.return_value = 'some-console'
+        self.bootloader.get_input_console.return_value = None
         self.bootloader.get_serial_line.return_value = 'some-serial'
         self.bootloader.get_use_disk_password.return_value = True
 
@@ -422,6 +423,7 @@ class TestXMLState:
                 clone=0,
                 partition_name='p.lxvar',
                 partition_type='t.linux',
+                partition_id=None,
                 mountpoint='/var',
                 filesystem='ext3',
                 label=''
@@ -1396,3 +1398,21 @@ class TestXMLState:
         assert self.state.btrfs_default_volume_requested() is False
         mock_get_btrfs_set_default_volume.return_value = None
         assert self.state.btrfs_default_volume_requested() is True
+
+    def test_get_certificates(self):
+        assert self.state.get_certificates() == ['/some/ca/filename']
+        assert self.state.get_certificates_target_distribution() == 'suse'
+        self.state.add_certificate('/new/file', 'rhel')
+        assert self.state.get_certificates() == [
+            '/new/file', '/some/ca/filename'
+        ]
+        assert self.state.get_certificates_target_distribution() == 'rhel'
+        self.state.add_certificate('/new/file', 'rhel')
+        assert self.state.get_certificates() == [
+            '/new/file', '/some/ca/filename'
+        ]
+        assert self.apt_state.get_certificates() == []
+        assert self.apt_state.get_certificates_target_distribution() == ''
+        self.apt_state.add_certificate('/new/file', 'debian')
+        assert self.apt_state.get_certificates() == ['/new/file']
+        assert self.apt_state.get_certificates_target_distribution() == 'debian'
